# sb::Data
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2005 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::Data;
use strict;
use sb ();
use sb::Object ();
use base qw( sb::Object );
use vars qw( $VERSION );
$VERSION = '0.07';
# 0.07 [2008/11/04] added classes to get the list of sb::Data::Object classes
# 0.06 [2007/08/07] changed load to add "limit" in %param
# 0.05 [2007/07/09] got rid of "return( undef )"
# 0.04 [2006/11/04] added private methods to call internally
# 0.03 [2006/07/04] changed add to call "create_new" instead of "create"
# 0.02 [2006/03/29] added count
# 0.01 [2006/03/06] use sb->get->driver instead of sb::Driver->get
# 0.00 [2005/10/20] generated
# --------------------------------------
# // public functions - static values
sub classes
{
	return (
		# ----------|> ----------|> ----------|> ----------|> ----------|> ----------|> ----------|
		'Amazon',    'Category',  'Config',    'Customdata','Entry',     'Image',     'Link',      
		'Message',   'Plugin',    'Session',   'Template',  'Trackback', 'User',      'Weblog',    
	);
}
# --------------------------------------
# // public functions - class method
sub load
{
	my $class = shift() . '::' . shift();
	_load_module($class) or return;
	my %param = ( # input parameters
		'cond'  => {},    # searching option
		'id'    => undef, # inidicates id to load directly
		'logic' => 'and', # logic factor for searching option
		'bgn'   => 0,     # offset of objects to load
		'num'   => -1,    # maximum of objects to load
		'sort'  => 'id',  # sorting option
		'order' => 0,     # sorting order 0:descent 1:ascent
		'limit' => undef, # parameter limitation
		@_
	);
	return if (!sb->get->driver);
	my @array = sb->get->driver->load($class,%param);
	return if (!@array);
	return ($#array == 0) ?  $array[0] : @array;
}
sub load_as_hash
{
	my $class = shift;
	my @array = $class->load(@_);
	return if ( !@array );
	return map { $_->id => $_ } @array;
}
sub count
{
	my $class = shift() . '::' . shift();
	_load_module($class) or return;
	my %param = ( # input parameters
		'cond'  => {},    # searching option
		'id'    => undef, # inidicates id to load directly
		'logic' => 'and', # logic factor for searching option
		'bgn'   => 0,     # offset of objects to load
		'num'   => -1,    # maximum of objects to load
		'sort'  => 'id',  # sorting option
		'order' => 0,     # sorting order 0:descent 1:ascent
		@_
	);
	return if (!sb->get->driver);
	return sb->get->driver->count($class,%param);
}
sub matched
{
	return if (!sb->get->driver);
	return sb->get->driver->matched_number;
}
sub update
{
	my $class = shift;
	my @objs  = @_; # objects to save
	return if (!sb->get->driver);
	sb->get->driver->save(@objs);
}
sub add
{
	my $class = shift() . '::' . shift();
	my %param = @_;
	_load_module($class) or return;
	return if (!sb->get->driver);
	$param{'id'} = sb->get->driver->new_id($class);
	return $class->create_new(%param);
}
# --------------------------------------
# // private functions
sub _load_module
{
	my $class = shift;
	return 1 if ( $class->isa('sb::Data::Object') );
	return sb::load_module($class);
}
1;
__END__
